API — SatNOGS Network 1.118 documentation

# API

SatNOGS Network API is a REST API to get scheduled jobs and post observation data. This document explains how to use the API to retrieve and post data for your application.

## Using API Data

API access is open to anyone. All API data are freely distributed under the CC BY-SA license.

## API Reference

The SatNOGS Network API is described by the SatNOGS Network OpenAPI document which follows the OpenAPI specification.

## Interactive API documentation

Based on the OpenAPI document for SatNOGS Network, an interactive API documentation is available, auto-generated by the OpenAPI generator.